@@ -293,18 +293,11 @@ char string_truth(char *input)
     {                
         return 0;
     }           
-    if (atoi(input))
-    {              
-        return 1;
-    }           
-    else
+    while (*input)
     {
-        while (*input)
+        if (*input++ != '0')
         {
-            if (*input++ != '0')
-            {
-                return 1;
-            }
+            return 1;
         }
     }
     return 0;
